@@ -7,5 +7,5 @@ from . import views
 
 
 urlpatterns = patterns('',
-    url(r"^message-tester$", views.generate_identity),
-    url(r"^message-tester/(?P<identity>\d+)$", views.message_tester))
+    url(r"^message-tester/$", views.generate_identity),
+    url(r"^message-tester/(?P<identity>\d+)/$", views.message_tester))
